# githunt
## Browse most stared repositories by date on Github from your command line

### This libray is inspired by the [Githunt](https://github.com/kamranahmedse/githunt) webapp created by [Kamran Ahmed](https://kamranahmed.info/), you can view it [here](https://kamranahmed.info/githunt/).

## TODO
[ ] Publish to PyPi as python library.